@@ -25,6 +25,8 @@
 #include "qcaprovider.h"
 
 #include <QFile>
+#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 #include <QUrl>
 
@@ -1248,7 +1250,7 @@ static QByteArray ipaddr_str2bin(const QString &str)
 {
     // ipv6
     if (str.contains(QLatin1Char(':'))) {
-        const QStringList parts = str.split(QLatin1Char(':'), QString::KeepEmptyParts);
+        const QStringList parts = str.split(QLatin1Char(':'), Qt::KeepEmptyParts);
         if (parts.count() < 3 || parts.count() > 8)
             return QByteArray();
 
@@ -1305,7 +1307,7 @@ static QByteArray ipaddr_str2bin(const QString &str)
 
         return ipv6;
     } else if (str.contains(QLatin1Char('.'))) {
-        const QStringList parts = str.split(QLatin1Char('.'), QString::KeepEmptyParts);
+        const QStringList parts = str.split(QLatin1Char('.'), Qt::KeepEmptyParts);
         if (parts.count() != 4)
             return QByteArray();
 
@@ -1343,11 +1345,11 @@ static bool cert_match_domain(const QString &certname, const QString &acedomain)
     name = name.toLower();
 
     // ensure the cert field contains valid characters only
-    if (QRegExp(QLatin1String("[^a-z0-9\\.\\*\\-]")).indexIn(name) >= 0)
+    if (QRegularExpression(QStringLiteral("[^a-z0-9\\.\\*\\-]")).match(name).hasMatch())
         return false;
 
     // hack into parts, and require at least 1 part
-    const QStringList parts_name = name.split(QLatin1Char('.'), QString::KeepEmptyParts);
+    const QStringList parts_name = name.split(QLatin1Char('.'), Qt::KeepEmptyParts);
     if (parts_name.isEmpty())
         return false;
 
@@ -1359,7 +1361,7 @@ static bool cert_match_domain(const QString &certname, const QString &acedomain)
     if (parts_name.count() >= 2 && parts_name[parts_name.count() - 2].contains(QLatin1Char('*')))
         return false;
 
-    const QStringList parts_compare = acedomain.split(QLatin1Char('.'), QString::KeepEmptyParts);
+    const QStringList parts_compare = acedomain.split(QLatin1Char('.'), Qt::KeepEmptyParts);
     if (parts_compare.isEmpty())
         return false;
 
