@@ -353,7 +353,7 @@ bool isSupported(const QStringList &features, const QString &provider)
 
 bool isSupported(const char *features, const QString &provider)
 {
-    return isSupported(QString::fromLatin1(features).split(QLatin1Char(','), QString::SkipEmptyParts), provider);
+    return isSupported(QString::fromLatin1(features).split(QLatin1Char(','), Qt::SkipEmptyParts), provider);
 }
 
 QStringList supportedFeatures()
@@ -541,7 +541,12 @@ static bool configIsValid(const QVariantMap &config)
     while (it.hasNext()) {
         it.next();
         const QVariant &v = it.value();
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        if (v.typeId() != QMetaType::QString && v.typeId() != QMetaType::Int && v.typeId() != QMetaType::Bool)
+#else
         if (v.type() != QVariant::String && v.type() != QVariant::Int && v.type() != QVariant::Bool)
+
+#endif
             return false;
     }
     return true;
