@@ -107,7 +107,7 @@ public:
     {
         SecureArray buf(size);
         for (int n = 0; n < (int)buf.size(); ++n)
-            buf[n] = (char)qrand();
+            buf[n] = (char)std::rand();
         return buf;
     }
 };
@@ -1250,10 +1250,10 @@ public:
     {
         const QDateTime now = QDateTime::currentDateTime();
 
-        uint t = now.toTime_t();
+        uint t = now.toSecsSinceEpoch();
         if (now.time().msec() > 0)
             t /= now.time().msec();
-        qsrand(t);
+        std::srand(t);
     }
 
     int version() const override
@@ -1330,7 +1330,11 @@ public:
             int  x  = s.indexOf(QLatin1Char(':'));
             bool ok = false;
             if (x != -1)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 2)
+                (void)QStringView(s).mid(x + 1).toInt(&ok);
+#else
                 s.midRef(x + 1).toInt(&ok);
+#endif
             if (!ok) {
                 plugin_priorities.removeAt(n);
                 --n;
